<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>Nastavitev miškine teme</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="46"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Izberite miškino temo (premik miške nad ikono prikaže animacijo). &lt;b&gt;Za uveljavitev sprememb je treba sejo LXQt ponovno zagnati.&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="23"/>
        <source>&amp;Install New Theme...</source>
        <translation>Namest&amp;i novo temo...</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="72"/>
        <source>LXQt session needs restart to view this change.</source>
        <translation>Za prikaz sprememb je treba sejo LXQt ponovno zagnati.</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="91"/>
        <source>&amp;Remove Theme</source>
        <translation>Odst&amp;rani temo</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="111"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="233"/>
        <source>XCurTheme error</source>
        <translation>Napaka XCurTheme</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="234"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>Aktivne teme se ne da odstraniti!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>Obrazec</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>LXQt ni uspel najti nobene teme za miško. Uporablja se privzeta tema X11. Pregledane mape so bile:</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>Prikaži...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
</context>
</TS>
